@@ -10,9 +10,9 @@ License:
 """
 from dataclasses import dataclass
 
-from illumio.util import ModifiableObject
+from illumio.util import MutableObject
 
 
 @dataclass
-class SecureConnectGateway(ModifiableObject):
+class SecureConnectGateway(MutableObject):
     pass
